#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-server
version:              0.20.3.0
visibility:           public
id:                   servant-server-0.20.3.0-Ch1ws9lTlMhG07GGXO4wFw
key:                  servant-server-0.20.3.0-Ch1ws9lTlMhG07GGXO4wFw
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  0fe7e5a397428cde4f0f26499c90b21a
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.ErrorFormatter
    Servant.Server.Internal.Handler
    Servant.Server.Internal.ResponseRender
    Servant.Server.Internal.RouteResult Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Server.UVerb Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-server-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-server-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-server-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-server
hs-libraries:         HSservant-server-0.20.3.0-Ch1ws9lTlMhG07GGXO4wFw
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-HSSC8ZpQ1EiHU6Qv1r7ZrY
    bytestring-0.11.5.3 constraints-0.14.3-EP2MC5YBgfxGTMXmfCYkT9
    containers-0.6.7 exceptions-0.10.7 filepath-1.4.300.1
    http-api-data-0.6.1-B4xD2REm6ADDTbBWwdbcen
    http-media-0.8.1.1-9xp3eR42oHREfldBp8wJZO
    http-types-0.12.4-JlSzXn1cYaxE3KCJJlxkWV
    monad-control-1.0.3.1-AyLS3fy4bfYGEyKgKmmIpm mtl-2.3.1
    network-3.1.4.0-5wCX3hTprFv2vYcKA8r7kN
    resourcet-1.2.6-2ZRVpZAaCnB5eaGpQGOamD
    servant-0.20.3.0-HxJc4HNE5VN5ggSNE5tRj0
    sop-core-0.5.0.2-1KOi1hjK2a7LcGI7gMT7tS
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j text-2.0.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-HZAxHvexxnqDnog08LgNq2
    wai-3.2.4-9U7mEZmQi9i5eOM7qE7ocW
    wai-app-static-3.1.9.1-JBb0zAW4GiwB32ExFvj7Rx
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

